@@ -1,4 +1,4 @@
-from gRPC_proto.user import user_pb2, user_pb2_grpc
+from .gRPC_proto.user import user_pb2, user_pb2_grpc
 
 
 class Admin:
