@@ -1,7 +1,7 @@
 import grpc
 import json
 
-from gRPC_proto.extractor import extractor_pb2, extractor_pb2_grpc
+from .gRPC_proto.extractor import extractor_pb2, extractor_pb2_grpc
 
 
 class Extractor:
