@@ -1,4 +1,4 @@
-from gRPC_proto.io_adaptors import io_adaptors_pb2, io_adaptors_pb2_grpc
+from .gRPC_proto.io_adaptors import io_adaptors_pb2, io_adaptors_pb2_grpc
 
 
 class FTP:
