@@ -1,7 +1,7 @@
 import json
 
 import grpc
-from gRPC_proto.user import user_pb2, user_pb2_grpc, auth_pb2_grpc, auth_pb2
+from .gRPC_proto.user import user_pb2, user_pb2_grpc, auth_pb2_grpc, auth_pb2
 
 
 class User:
